Package com.chargebee
Class Environment
java.lang.Object
com.chargebee.Environment
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final Stringfinal StringYou can generate API keys from the ChargeBee web interface.static final StringintTimeout value, in milliseconds, to be used when trying to conect to the chargebee api server.booleanstatic final StringintTimeout value, in milliseconds, to be used when reading response from the chargebee api server.final StringYour chargebee subdomain. -
Constructor Summary
ConstructorsConstructorDescriptionEnvironment(String siteName, String apiKey) Environment(String siteName, String apiKey, RequestInterceptor reqInterceptor) -
Method Summary
Modifier and TypeMethodDescriptionapiBaseUrlWithSubDomain(String subDomain) static voidstatic Environmentstatic voidreqInterceptor(RequestInterceptor reqInterceptor) static voidupdateConnectTimeoutInMillis(int connectTimeout) voidupdateEnableDebugLogging(boolean enableDebugLogging) static voidupdateReadTimeoutInMillis(int readTimeout) voidupdateRetryConfig(RetryConfig retryConfig)
-
Field Details
-
apiKey
You can generate API keys from the ChargeBee web interface. -
siteName
Your chargebee subdomain. Could be your sandbox or production. -
connectTimeout
public int connectTimeoutTimeout value, in milliseconds, to be used when trying to conect to the chargebee api server. If the timeout expires before the connection can be established, a java.net.SocketTimeoutException is raised. A timeout of zero is interpreted as an infinite timeout. -
readTimeout
public int readTimeoutTimeout value, in milliseconds, to be used when reading response from the chargebee api server. If the timeout expires before there is data available for read, a java.net.SocketTimeoutException is raised. A timeout of zero is interpreted as an infinite timeout. -
retryConfig
-
enableDebugLogging
public boolean enableDebugLogging -
CHARSET
- See Also:
-
API_VERSION
- See Also:
-
LIBRARY_VERSION
- See Also:
-
-
Constructor Details
-
Environment
-
Environment
-
-
Method Details
-
configure
-
reqInterceptor
-
reqInterceptor
-
defaultConfig
-
apiBaseUrl
-
apiBaseUrlWithSubDomain
-
updateConnectTimeoutInMillis
public static void updateConnectTimeoutInMillis(int connectTimeout) -
updateReadTimeoutInMillis
public static void updateReadTimeoutInMillis(int readTimeout) -
updateRetryConfig
-
updateEnableDebugLogging
public void updateEnableDebugLogging(boolean enableDebugLogging)
-