Package com.chargebee.gdata
package com.chargebee.gdata
-
ClassDescriptionAn object that converts literal text into a format safe for inclusion in a particular context (such as an XML document).A
UnicodeEscaperthat escapes some set of Java characters using the URI percent encoding scheme.AnEscaperthat converts literal text into a format safe for inclusion in a particular context (such as an XML document).