Uses of Enum
com.chargebee.internal.HttpUtil.Method
Packages that use HttpUtil.Method
-
Uses of HttpUtil.Method in com.chargebee.internal
Methods in com.chargebee.internal that return HttpUtil.MethodModifier and TypeMethodDescriptionRequest.httpMeth()static HttpUtil.MethodReturns the enum constant of this type with the specified name.static HttpUtil.Method[]HttpUtil.Method.values()Returns an array containing the constants of this enum type, in the order they are declared.Constructors in com.chargebee.internal with parameters of type HttpUtil.MethodModifierConstructorDescriptionBatchRequest(HttpUtil.Method httpMeth, String uri) BatchRequest(HttpUtil.Method httpMeth, String uri, String pathParamName) Request(HttpUtil.Method httpMeth, String uri) Request(HttpUtil.Method httpMeth, String uri, String pathParam) Request(HttpUtil.Method httpMeth, String uri, String pathParam, String subDomain) Request(HttpUtil.Method httpMethod, String uri, String pathParam, String subDomain, boolean isContentTypeJson)