Enum Addon.PeriodUnit

java.lang.Object
java.lang.Enum<Addon.PeriodUnit>
com.chargebee.models.Addon.PeriodUnit
All Implemented Interfaces:
Serializable, Comparable<Addon.PeriodUnit>, java.lang.constant.Constable
Enclosing class:
Addon

public static enum Addon.PeriodUnit extends Enum<Addon.PeriodUnit>
  • Enum Constant Details

  • Method Details

    • values

      public static Addon.PeriodUnit[] values()
      Returns an array containing the constants of this enum type, in the order they are declared.
      Returns:
      an array containing the constants of this enum type, in the order they are declared
    • valueOf

      public static Addon.PeriodUnit valueOf(String name)
      Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum type has no constant with the specified name
      NullPointerException - if the argument is null