Enum Addon.Type

java.lang.Object
java.lang.Enum<Addon.Type>
com.chargebee.models.Addon.Type
All Implemented Interfaces:
Serializable, Comparable<Addon.Type>, java.lang.constant.Constable
Enclosing class:
Addon

@Deprecated public static enum Addon.Type extends Enum<Addon.Type>
Deprecated.
  • Enum Constant Details

    • ON_OFF

      public static final Addon.Type ON_OFF
      Deprecated.
    • QUANTITY

      public static final Addon.Type QUANTITY
      Deprecated.
    • TIERED

      public static final Addon.Type TIERED
      Deprecated.
    • VOLUME

      public static final Addon.Type VOLUME
      Deprecated.
    • STAIRSTEP

      public static final Addon.Type STAIRSTEP
      Deprecated.
    • _UNKNOWN

      public static final Addon.Type _UNKNOWN
      Deprecated.
  • Method Details

    • values

      public static Addon.Type[] values()
      Deprecated.
      Returns an array containing the constants of this enum type, in the order they are declared.
      Returns:
      an array containing the constants of this enum type, in the order they are declared
    • valueOf

      public static Addon.Type valueOf(String name)
      Deprecated.
      Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum type has no constant with the specified name
      NullPointerException - if the argument is null