public static enum BusinessEntityTransfer.ReasonCode extends Enum<BusinessEntityTransfer.ReasonCode>
| Enum Constant and Description |
|---|
_UNKNOWN |
CORRECTION |
| Modifier and Type | Method and Description |
|---|---|
static BusinessEntityTransfer.ReasonCode |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static BusinessEntityTransfer.ReasonCode[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final BusinessEntityTransfer.ReasonCode CORRECTION
public static final BusinessEntityTransfer.ReasonCode _UNKNOWN
public static BusinessEntityTransfer.ReasonCode[] values()
for (BusinessEntityTransfer.ReasonCode c : BusinessEntityTransfer.ReasonCode.values()) System.out.println(c);
public static BusinessEntityTransfer.ReasonCode valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2024 ChargeBee. All rights reserved.