public static enum BusinessEntityTransfer.ResourceType extends Enum<BusinessEntityTransfer.ResourceType>
| Enum Constant and Description |
|---|
_UNKNOWN |
CUSTOMER |
SUBSCRIPTION |
| Modifier and Type | Method and Description |
|---|---|
static BusinessEntityTransfer.ResourceType |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static BusinessEntityTransfer.ResourceType[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final BusinessEntityTransfer.ResourceType CUSTOMER
public static final BusinessEntityTransfer.ResourceType SUBSCRIPTION
public static final BusinessEntityTransfer.ResourceType _UNKNOWN
public static BusinessEntityTransfer.ResourceType[] values()
for (BusinessEntityTransfer.ResourceType c : BusinessEntityTransfer.ResourceType.values()) System.out.println(c);
public static BusinessEntityTransfer.ResourceType valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2024 ChargeBee. All rights reserved.