public static enum Card.CardType extends Enum<Card.CardType>
| Enum Constant and Description |
|---|
_UNKNOWN |
AMERICAN_EXPRESS |
ARGENCARD |
BANCONTACT |
CABAL |
CARNET |
CARTES_BANCAIRES |
CENCOSUD |
CMR_FALABELLA |
DANKORT |
DINERS_CLUB |
DISCOVER |
ELO |
HIPERCARD |
JCB |
MAESTRO |
MASTERCARD |
NATIVA |
NOT_APPLICABLE |
OTHER |
RUPAY |
TARJETA_NARANJA |
VISA |
| Modifier and Type | Method and Description |
|---|---|
static Card.CardType |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static Card.CardType[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Card.CardType VISA
public static final Card.CardType MASTERCARD
public static final Card.CardType AMERICAN_EXPRESS
public static final Card.CardType DISCOVER
public static final Card.CardType JCB
public static final Card.CardType DINERS_CLUB
public static final Card.CardType BANCONTACT
public static final Card.CardType CMR_FALABELLA
public static final Card.CardType TARJETA_NARANJA
public static final Card.CardType NATIVA
public static final Card.CardType CENCOSUD
public static final Card.CardType CABAL
public static final Card.CardType ARGENCARD
public static final Card.CardType ELO
public static final Card.CardType HIPERCARD
public static final Card.CardType CARNET
public static final Card.CardType RUPAY
public static final Card.CardType MAESTRO
public static final Card.CardType DANKORT
public static final Card.CardType CARTES_BANCAIRES
public static final Card.CardType OTHER
public static final Card.CardType NOT_APPLICABLE
public static final Card.CardType _UNKNOWN
public static Card.CardType[] values()
for (Card.CardType c : Card.CardType.values()) System.out.println(c);
public static Card.CardType valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2025 ChargeBee. All rights reserved.