com.chargebee.models
Enum ContractTerm.Status

java.lang.Object
  extended by java.lang.Enum<ContractTerm.Status>
      extended by com.chargebee.models.ContractTerm.Status
All Implemented Interfaces:
Serializable, Comparable<ContractTerm.Status>
Enclosing class:
ContractTerm

public static enum ContractTerm.Status
extends Enum<ContractTerm.Status>


Enum Constant Summary
_UNKNOWN
           
ACTIVE
           
CANCELLED
           
COMPLETED
           
TERMINATED
           
 
Method Summary
static ContractTerm.Status valueOf(String name)
          Returns the enum constant of this type with the specified name.
static ContractTerm.Status[] values()
          Returns an array containing the constants of this enum type, in the order they are declared.
 
Methods inherited from class java.lang.Enum
clone, compareTo, equals, finalize, getDeclaringClass, hashCode, name, ordinal, toString, valueOf
 
Methods inherited from class java.lang.Object
getClass, notify, notifyAll, wait, wait, wait
 

Enum Constant Detail

ACTIVE

public static final ContractTerm.Status ACTIVE

COMPLETED

public static final ContractTerm.Status COMPLETED

CANCELLED

public static final ContractTerm.Status CANCELLED

TERMINATED

public static final ContractTerm.Status TERMINATED

_UNKNOWN

public static final ContractTerm.Status _UNKNOWN
Method Detail

values

public static ContractTerm.Status[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:
for (ContractTerm.Status c : ContractTerm.Status.values())
    System.out.println(c);

Returns:
an array containing the constants of this enum type, in the order they are declared

valueOf

public static ContractTerm.Status valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)

Parameters:
name - the name of the enum constant to be returned.
Returns:
the enum constant with the specified name
Throws:
IllegalArgumentException - if this enum type has no constant with the specified name
NullPointerException - if the argument is null


Copyright © 2020 ChargeBee. All Rights Reserved.