public static enum CreditNote.Allocation.TaxApplication extends Enum<CreditNote.Allocation.TaxApplication>
| Modifier and Type | Method and Description |
|---|---|
static CreditNote.Allocation.TaxApplication |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static CreditNote.Allocation.TaxApplication[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final CreditNote.Allocation.TaxApplication PRE_TAX
public static final CreditNote.Allocation.TaxApplication POST_TAX
public static final CreditNote.Allocation.TaxApplication _UNKNOWN
public static CreditNote.Allocation.TaxApplication[] values()
for (CreditNote.Allocation.TaxApplication c : CreditNote.Allocation.TaxApplication.values()) System.out.println(c);
public static CreditNote.Allocation.TaxApplication valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2025 ChargeBee. All rights reserved.