public static enum CreditNote.Discount.DiscountType extends Enum<CreditNote.Discount.DiscountType>
| Enum Constant and Description |
|---|
_UNKNOWN |
FIXED_AMOUNT |
PERCENTAGE |
| Modifier and Type | Method and Description |
|---|---|
static CreditNote.Discount.DiscountType |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static CreditNote.Discount.DiscountType[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final CreditNote.Discount.DiscountType FIXED_AMOUNT
public static final CreditNote.Discount.DiscountType PERCENTAGE
public static final CreditNote.Discount.DiscountType _UNKNOWN
public static CreditNote.Discount.DiscountType[] values()
for (CreditNote.Discount.DiscountType c : CreditNote.Discount.DiscountType.values()) System.out.println(c);
public static CreditNote.Discount.DiscountType valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2025 ChargeBee. All rights reserved.