public static enum Customer.PaymentMethod.Type extends Enum<Customer.PaymentMethod.Type>
| Enum Constant and Description |
|---|
_UNKNOWN |
ALIPAY |
AMAZON_PAYMENTS |
APPLE_PAY |
AUTOMATED_BANK_TRANSFER |
BANCONTACT |
CARD |
DIRECT_DEBIT |
DOTPAY |
FASTER_PAYMENTS |
GENERIC |
GIROPAY |
GOOGLE_PAY |
IDEAL |
KLARNA_PAY_NOW |
NETBANKING_EMANDATES |
ONLINE_BANKING_POLAND |
PAY_TO |
PAYPAL_EXPRESS_CHECKOUT |
SEPA_INSTANT_TRANSFER |
SOFORT |
UNIONPAY |
UPI |
VENMO |
WECHAT_PAY |
| Modifier and Type | Method and Description |
|---|---|
static Customer.PaymentMethod.Type |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static Customer.PaymentMethod.Type[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Customer.PaymentMethod.Type CARD
public static final Customer.PaymentMethod.Type PAYPAL_EXPRESS_CHECKOUT
public static final Customer.PaymentMethod.Type AMAZON_PAYMENTS
public static final Customer.PaymentMethod.Type DIRECT_DEBIT
public static final Customer.PaymentMethod.Type GENERIC
public static final Customer.PaymentMethod.Type ALIPAY
public static final Customer.PaymentMethod.Type UNIONPAY
public static final Customer.PaymentMethod.Type APPLE_PAY
public static final Customer.PaymentMethod.Type WECHAT_PAY
public static final Customer.PaymentMethod.Type IDEAL
public static final Customer.PaymentMethod.Type GOOGLE_PAY
public static final Customer.PaymentMethod.Type SOFORT
public static final Customer.PaymentMethod.Type BANCONTACT
public static final Customer.PaymentMethod.Type GIROPAY
public static final Customer.PaymentMethod.Type DOTPAY
public static final Customer.PaymentMethod.Type UPI
public static final Customer.PaymentMethod.Type NETBANKING_EMANDATES
public static final Customer.PaymentMethod.Type VENMO
public static final Customer.PaymentMethod.Type PAY_TO
public static final Customer.PaymentMethod.Type FASTER_PAYMENTS
public static final Customer.PaymentMethod.Type SEPA_INSTANT_TRANSFER
public static final Customer.PaymentMethod.Type AUTOMATED_BANK_TRANSFER
public static final Customer.PaymentMethod.Type KLARNA_PAY_NOW
public static final Customer.PaymentMethod.Type ONLINE_BANKING_POLAND
public static final Customer.PaymentMethod.Type _UNKNOWN
public static Customer.PaymentMethod.Type[] values()
for (Customer.PaymentMethod.Type c : Customer.PaymentMethod.Type.values()) System.out.println(c);
public static Customer.PaymentMethod.Type valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2024 ChargeBee. All rights reserved.