public static enum Entitlement.EntityType extends Enum<Entitlement.EntityType>
| Enum Constant and Description |
|---|
_UNKNOWN |
ADDON |
ADDON_PRICE |
CHARGE |
PLAN |
PLAN_PRICE |
| Modifier and Type | Method and Description |
|---|---|
static Entitlement.EntityType |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static Entitlement.EntityType[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Entitlement.EntityType PLAN
public static final Entitlement.EntityType ADDON
public static final Entitlement.EntityType CHARGE
public static final Entitlement.EntityType PLAN_PRICE
public static final Entitlement.EntityType ADDON_PRICE
public static final Entitlement.EntityType _UNKNOWN
public static Entitlement.EntityType[] values()
for (Entitlement.EntityType c : Entitlement.EntityType.values()) System.out.println(c);
public static Entitlement.EntityType valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2025 ChargeBee. All rights reserved.