Package com.chargebee.models
Enum Event.WebhookStatus
- All Implemented Interfaces:
Serializable,Comparable<Event.WebhookStatus>,java.lang.constant.Constable
- Enclosing class:
- Event
Deprecated.
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionDeprecated.Deprecated.Deprecated.Deprecated.Deprecated.Deprecated.Deprecated.Deprecated.Deprecated. -
Method Summary
Modifier and TypeMethodDescriptionstatic Event.WebhookStatusDeprecated.Returns the enum constant of this type with the specified name.static Event.WebhookStatus[]values()Deprecated.Returns an array containing the constants of this enum type, in the order they are declared.
-
Enum Constant Details
-
NOT_CONFIGURED
Deprecated. -
SCHEDULED
Deprecated. -
SUCCEEDED
Deprecated. -
RE_SCHEDULED
Deprecated. -
FAILED
Deprecated. -
SKIPPED
Deprecated. -
NOT_APPLICABLE
Deprecated. -
DISABLED
Deprecated. -
_UNKNOWN
Deprecated.
-
-
Method Details
-
values
Deprecated.Returns an array containing the constants of this enum type, in the order they are declared.- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
Deprecated.Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-