public static enum Installment.Status extends Enum<Installment.Status>
| Enum Constant and Description |
|---|
_UNKNOWN |
PAID |
PAYMENT_DUE |
POSTED |
| Modifier and Type | Method and Description |
|---|---|
static Installment.Status |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static Installment.Status[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Installment.Status POSTED
public static final Installment.Status PAYMENT_DUE
public static final Installment.Status PAID
public static final Installment.Status _UNKNOWN
public static Installment.Status[] values()
for (Installment.Status c : Installment.Status.values()) System.out.println(c);
public static Installment.Status valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2024 ChargeBee. All rights reserved.