public static enum InstallmentConfig.PeriodUnit extends Enum<InstallmentConfig.PeriodUnit>
| Modifier and Type | Method and Description |
|---|---|
static InstallmentConfig.PeriodUnit |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static InstallmentConfig.PeriodUnit[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final InstallmentConfig.PeriodUnit DAY
public static final InstallmentConfig.PeriodUnit WEEK
public static final InstallmentConfig.PeriodUnit MONTH
public static final InstallmentConfig.PeriodUnit _UNKNOWN
public static InstallmentConfig.PeriodUnit[] values()
for (InstallmentConfig.PeriodUnit c : InstallmentConfig.PeriodUnit.values()) System.out.println(c);
public static InstallmentConfig.PeriodUnit valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2024 ChargeBee. All rights reserved.