public static enum Item.BundleConfiguration.Type extends Enum<Item.BundleConfiguration.Type>
| Modifier and Type | Method and Description |
|---|---|
static Item.BundleConfiguration.Type |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static Item.BundleConfiguration.Type[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Item.BundleConfiguration.Type FIXED
public static final Item.BundleConfiguration.Type _UNKNOWN
public static Item.BundleConfiguration.Type[] values()
for (Item.BundleConfiguration.Type c : Item.BundleConfiguration.Type.values()) System.out.println(c);
public static Item.BundleConfiguration.Type valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2024 ChargeBee. All rights reserved.