public static enum PaymentIntent.PaymentMethodType extends Enum<PaymentIntent.PaymentMethodType>
| Enum Constant and Description |
|---|
_UNKNOWN |
AMAZON_PAYMENTS |
APPLE_PAY |
BANCONTACT |
BOLETO |
CARD |
DIRECT_DEBIT |
DOTPAY |
FASTER_PAYMENTS |
GIROPAY |
GOOGLE_PAY |
IDEAL |
NETBANKING_EMANDATES |
PAY_TO |
PAYPAL_EXPRESS_CHECKOUT |
SEPA_INSTANT_TRANSFER |
SOFORT |
UPI |
VENMO |
| Modifier and Type | Method and Description |
|---|---|
static PaymentIntent.PaymentMethodType |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static PaymentIntent.PaymentMethodType[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final PaymentIntent.PaymentMethodType CARD
public static final PaymentIntent.PaymentMethodType IDEAL
public static final PaymentIntent.PaymentMethodType SOFORT
public static final PaymentIntent.PaymentMethodType BANCONTACT
public static final PaymentIntent.PaymentMethodType GOOGLE_PAY
public static final PaymentIntent.PaymentMethodType DOTPAY
public static final PaymentIntent.PaymentMethodType GIROPAY
public static final PaymentIntent.PaymentMethodType APPLE_PAY
public static final PaymentIntent.PaymentMethodType UPI
public static final PaymentIntent.PaymentMethodType NETBANKING_EMANDATES
public static final PaymentIntent.PaymentMethodType PAYPAL_EXPRESS_CHECKOUT
public static final PaymentIntent.PaymentMethodType DIRECT_DEBIT
public static final PaymentIntent.PaymentMethodType BOLETO
public static final PaymentIntent.PaymentMethodType VENMO
public static final PaymentIntent.PaymentMethodType AMAZON_PAYMENTS
public static final PaymentIntent.PaymentMethodType PAY_TO
public static final PaymentIntent.PaymentMethodType FASTER_PAYMENTS
public static final PaymentIntent.PaymentMethodType SEPA_INSTANT_TRANSFER
public static final PaymentIntent.PaymentMethodType _UNKNOWN
public static PaymentIntent.PaymentMethodType[] values()
for (PaymentIntent.PaymentMethodType c : PaymentIntent.PaymentMethodType.values()) System.out.println(c);
public static PaymentIntent.PaymentMethodType valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2024 ChargeBee. All rights reserved.