com.chargebee.models
Enum QuoteLineGroup.ChargeEvent

java.lang.Object
  extended by java.lang.Enum<QuoteLineGroup.ChargeEvent>
      extended by com.chargebee.models.QuoteLineGroup.ChargeEvent
All Implemented Interfaces:
Serializable, Comparable<QuoteLineGroup.ChargeEvent>
Enclosing class:
QuoteLineGroup

public static enum QuoteLineGroup.ChargeEvent
extends Enum<QuoteLineGroup.ChargeEvent>


Enum Constant Summary
_UNKNOWN
           
IMMEDIATE
           
SUBSCRIPTION_CHANGE
           
SUBSCRIPTION_CREATION
           
SUBSCRIPTION_RENEWAL
           
TRIAL_START
           
 
Method Summary
static QuoteLineGroup.ChargeEvent valueOf(String name)
          Returns the enum constant of this type with the specified name.
static QuoteLineGroup.ChargeEvent[] values()
          Returns an array containing the constants of this enum type, in the order they are declared.
 
Methods inherited from class java.lang.Enum
clone, compareTo, equals, finalize, getDeclaringClass, hashCode, name, ordinal, toString, valueOf
 
Methods inherited from class java.lang.Object
getClass, notify, notifyAll, wait, wait, wait
 

Enum Constant Detail

IMMEDIATE

public static final QuoteLineGroup.ChargeEvent IMMEDIATE

SUBSCRIPTION_CREATION

public static final QuoteLineGroup.ChargeEvent SUBSCRIPTION_CREATION

TRIAL_START

public static final QuoteLineGroup.ChargeEvent TRIAL_START

SUBSCRIPTION_CHANGE

public static final QuoteLineGroup.ChargeEvent SUBSCRIPTION_CHANGE

SUBSCRIPTION_RENEWAL

public static final QuoteLineGroup.ChargeEvent SUBSCRIPTION_RENEWAL

_UNKNOWN

public static final QuoteLineGroup.ChargeEvent _UNKNOWN
Method Detail

values

public static QuoteLineGroup.ChargeEvent[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:
for (QuoteLineGroup.ChargeEvent c : QuoteLineGroup.ChargeEvent.values())
    System.out.println(c);

Returns:
an array containing the constants of this enum type, in the order they are declared

valueOf

public static QuoteLineGroup.ChargeEvent valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)

Parameters:
name - the name of the enum constant to be returned.
Returns:
the enum constant with the specified name
Throws:
IllegalArgumentException - if this enum type has no constant with the specified name
NullPointerException - if the argument is null


Copyright © 2020 ChargeBee. All Rights Reserved.