public static enum RecordedPurchase.Source extends Enum<RecordedPurchase.Source>
| Enum Constant and Description |
|---|
_UNKNOWN |
APPLE_APP_STORE |
| Modifier and Type | Method and Description |
|---|---|
static RecordedPurchase.Source |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static RecordedPurchase.Source[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final RecordedPurchase.Source APPLE_APP_STORE
public static final RecordedPurchase.Source _UNKNOWN
public static RecordedPurchase.Source[] values()
for (RecordedPurchase.Source c : RecordedPurchase.Source.values()) System.out.println(c);
public static RecordedPurchase.Source valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2024 ChargeBee. All rights reserved.