public static enum Rule.Status extends Enum<Rule.Status>
| Modifier and Type | Method and Description |
|---|---|
static Rule.Status |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static Rule.Status[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Rule.Status ACTIVE
public static final Rule.Status DISABLED
public static final Rule.Status _UNKNOWN
public static Rule.Status[] values()
for (Rule.Status c : Rule.Status.values()) System.out.println(c);
public static Rule.Status valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2025 ChargeBee. All rights reserved.