com.chargebee.models
Enum Subscription.ContractTerm.ActionAtTermEnd

java.lang.Object
  extended by java.lang.Enum<Subscription.ContractTerm.ActionAtTermEnd>
      extended by com.chargebee.models.Subscription.ContractTerm.ActionAtTermEnd
All Implemented Interfaces:
Serializable, Comparable<Subscription.ContractTerm.ActionAtTermEnd>
Enclosing class:
Subscription.ContractTerm

public static enum Subscription.ContractTerm.ActionAtTermEnd
extends Enum<Subscription.ContractTerm.ActionAtTermEnd>


Enum Constant Summary
_UNKNOWN
           
CANCEL
           
EVERGREEN
           
RENEW
           
RENEW_ONCE
           
 
Method Summary
static Subscription.ContractTerm.ActionAtTermEnd valueOf(String name)
          Returns the enum constant of this type with the specified name.
static Subscription.ContractTerm.ActionAtTermEnd[] values()
          Returns an array containing the constants of this enum type, in the order they are declared.
 
Methods inherited from class java.lang.Enum
clone, compareTo, equals, finalize, getDeclaringClass, hashCode, name, ordinal, toString, valueOf
 
Methods inherited from class java.lang.Object
getClass, notify, notifyAll, wait, wait, wait
 

Enum Constant Detail

RENEW

public static final Subscription.ContractTerm.ActionAtTermEnd RENEW

EVERGREEN

public static final Subscription.ContractTerm.ActionAtTermEnd EVERGREEN

CANCEL

public static final Subscription.ContractTerm.ActionAtTermEnd CANCEL

RENEW_ONCE

public static final Subscription.ContractTerm.ActionAtTermEnd RENEW_ONCE

_UNKNOWN

public static final Subscription.ContractTerm.ActionAtTermEnd _UNKNOWN
Method Detail

values

public static Subscription.ContractTerm.ActionAtTermEnd[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:
for (Subscription.ContractTerm.ActionAtTermEnd c : Subscription.ContractTerm.ActionAtTermEnd.values())
    System.out.println(c);

Returns:
an array containing the constants of this enum type, in the order they are declared

valueOf

public static Subscription.ContractTerm.ActionAtTermEnd valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)

Parameters:
name - the name of the enum constant to be returned.
Returns:
the enum constant with the specified name
Throws:
IllegalArgumentException - if this enum type has no constant with the specified name
NullPointerException - if the argument is null


Copyright © 2020 ChargeBee. All Rights Reserved.