public static enum UsageFile.Status extends Enum<UsageFile.Status>
| Enum Constant and Description |
|---|
_UNKNOWN |
FAILED |
IMPORTED |
PROCESSED |
PROCESSING |
QUEUED |
| Modifier and Type | Method and Description |
|---|---|
static UsageFile.Status |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static UsageFile.Status[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final UsageFile.Status QUEUED
public static final UsageFile.Status IMPORTED
public static final UsageFile.Status PROCESSING
public static final UsageFile.Status PROCESSED
public static final UsageFile.Status FAILED
public static final UsageFile.Status _UNKNOWN
public static UsageFile.Status[] values()
for (UsageFile.Status c : UsageFile.Status.values()) System.out.println(c);
public static UsageFile.Status valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2025 ChargeBee. All rights reserved.