Uses of Enum
com.chargebee.models.Addon.PeriodUnit
Packages that use Addon.PeriodUnit
-
Uses of Addon.PeriodUnit in com.chargebee.models
Methods in com.chargebee.models that return Addon.PeriodUnitModifier and TypeMethodDescriptionAddon.periodUnit()static Addon.PeriodUnitReturns the enum constant of this type with the specified name.static Addon.PeriodUnit[]Addon.PeriodUnit.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.chargebee.models that return types with arguments of type Addon.PeriodUnitModifier and TypeMethodDescriptionExport.AddonsRequest.addonPeriodUnit()Addon.AddonListRequest.periodUnit()Methods in com.chargebee.models with parameters of type Addon.PeriodUnitModifier and TypeMethodDescriptionAddon.CreateRequest.periodUnit(Addon.PeriodUnit periodUnit) Addon.UpdateRequest.periodUnit(Addon.PeriodUnit periodUnit)