Uses of Enum
com.chargebee.models.Addon.ShippingFrequencyPeriodUnit
Packages that use Addon.ShippingFrequencyPeriodUnit
-
Uses of Addon.ShippingFrequencyPeriodUnit in com.chargebee.models
Methods in com.chargebee.models that return Addon.ShippingFrequencyPeriodUnitModifier and TypeMethodDescriptionAddon.shippingFrequencyPeriodUnit()Returns the enum constant of this type with the specified name.static Addon.ShippingFrequencyPeriodUnit[]Addon.ShippingFrequencyPeriodUnit.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.chargebee.models with parameters of type Addon.ShippingFrequencyPeriodUnitModifier and TypeMethodDescriptionAddon.CreateRequest.shippingFrequencyPeriodUnit(Addon.ShippingFrequencyPeriodUnit shippingFrequencyPeriodUnit) Addon.UpdateRequest.shippingFrequencyPeriodUnit(Addon.ShippingFrequencyPeriodUnit shippingFrequencyPeriodUnit)