Uses of Enum
com.chargebee.models.BusinessEntityTransfer.ReasonCode
Packages that use BusinessEntityTransfer.ReasonCode
-
Uses of BusinessEntityTransfer.ReasonCode in com.chargebee.models
Methods in com.chargebee.models that return BusinessEntityTransfer.ReasonCodeModifier and TypeMethodDescriptionBusinessEntityTransfer.reasonCode()Returns the enum constant of this type with the specified name.static BusinessEntityTransfer.ReasonCode[]BusinessEntityTransfer.ReasonCode.values()Returns an array containing the constants of this enum type, in the order they are declared.