Uses of Enum
com.chargebee.models.CouponCode.Status
Packages that use CouponCode.Status
-
Uses of CouponCode.Status in com.chargebee.models
Methods in com.chargebee.models that return CouponCode.StatusModifier and TypeMethodDescriptionCouponCode.status()static CouponCode.StatusReturns the enum constant of this type with the specified name.static CouponCode.Status[]CouponCode.Status.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.chargebee.models that return types with arguments of type CouponCode.Status