Uses of Enum
com.chargebee.models.CreditNote.Allocation.TaxApplication
Packages that use CreditNote.Allocation.TaxApplication
-
Uses of CreditNote.Allocation.TaxApplication in com.chargebee.models
Methods in com.chargebee.models that return CreditNote.Allocation.TaxApplicationModifier and TypeMethodDescriptionCreditNote.Allocation.taxApplication()Returns the enum constant of this type with the specified name.static CreditNote.Allocation.TaxApplication[]CreditNote.Allocation.TaxApplication.values()Returns an array containing the constants of this enum type, in the order they are declared.