Uses of Enum
com.chargebee.models.CreditNote.Status
Packages that use CreditNote.Status
-
Uses of CreditNote.Status in com.chargebee.models
Methods in com.chargebee.models that return CreditNote.StatusModifier and TypeMethodDescriptionInvoice.AdjustmentCreditNote.cnStatus()Invoice.AppliedCredit.cnStatus()Invoice.IssuedCreditNote.cnStatus()Transaction.LinkedCreditNote.cnStatus()CreditNote.status()static CreditNote.StatusReturns the enum constant of this type with the specified name.static CreditNote.Status[]CreditNote.Status.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.chargebee.models that return types with arguments of type CreditNote.StatusModifier and TypeMethodDescriptionExport.CreditNotesRequest.creditNoteStatus()CreditNote.CreditNoteListRequest.status()Methods in com.chargebee.models with parameters of type CreditNote.StatusModifier and TypeMethodDescriptionCreditNote.ImportCreditNoteRequest.status(CreditNote.Status status)