Uses of Enum
com.chargebee.models.Customer.CardStatus
Packages that use Customer.CardStatus
-
Uses of Customer.CardStatus in com.chargebee.models
Methods in com.chargebee.models that return Customer.CardStatusModifier and TypeMethodDescriptionCustomer.cardStatus()Deprecated.static Customer.CardStatusDeprecated.Returns the enum constant of this type with the specified name.static Customer.CardStatus[]Customer.CardStatus.values()Deprecated.Returns an array containing the constants of this enum type, in the order they are declared.