| Package | Description |
|---|---|
| com.chargebee.models |
| Modifier and Type | Method and Description |
|---|---|
InstallmentConfig.PeriodUnit |
InstallmentConfig.periodUnit() |
static InstallmentConfig.PeriodUnit |
InstallmentConfig.PeriodUnit.valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static InstallmentConfig.PeriodUnit[] |
InstallmentConfig.PeriodUnit.values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
| Modifier and Type | Method and Description |
|---|---|
InstallmentConfig.CreateRequest |
InstallmentConfig.CreateRequest.periodUnit(InstallmentConfig.PeriodUnit periodUnit) |
Copyright © 2024 ChargeBee. All rights reserved.