Uses of Enum
com.chargebee.models.Invoice.Status
Packages that use Invoice.Status
-
Uses of Invoice.Status in com.chargebee.models
Methods in com.chargebee.models that return Invoice.StatusModifier and TypeMethodDescriptionCreditNote.Allocation.invoiceStatus()Transaction.LinkedInvoice.invoiceStatus()Invoice.status()static Invoice.StatusReturns the enum constant of this type with the specified name.static Invoice.Status[]Invoice.Status.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.chargebee.models that return types with arguments of type Invoice.StatusModifier and TypeMethodDescriptionExport.DeferredRevenueRequest.invoiceStatus()Export.InvoicesRequest.invoiceStatus()Export.RevenueRecognitionRequest.invoiceStatus()Invoice.InvoiceListRequest.status()Methods in com.chargebee.models with parameters of type Invoice.Status