Uses of Enum
com.chargebee.models.OfferFulfillment.Error.Code
Packages that use OfferFulfillment.Error.Code
-
Uses of OfferFulfillment.Error.Code in com.chargebee.models
Methods in com.chargebee.models that return OfferFulfillment.Error.CodeModifier and TypeMethodDescriptionOfferFulfillment.Error.code()static OfferFulfillment.Error.CodeReturns the enum constant of this type with the specified name.static OfferFulfillment.Error.Code[]OfferFulfillment.Error.Code.values()Returns an array containing the constants of this enum type, in the order they are declared.