Uses of Enum
com.chargebee.models.Order.LinkedCreditNote.Status
Packages that use Order.LinkedCreditNote.Status
-
Uses of Order.LinkedCreditNote.Status in com.chargebee.models
Methods in com.chargebee.models that return Order.LinkedCreditNote.StatusModifier and TypeMethodDescriptionOrder.LinkedCreditNote.status()Returns the enum constant of this type with the specified name.static Order.LinkedCreditNote.Status[]Order.LinkedCreditNote.Status.values()Returns an array containing the constants of this enum type, in the order they are declared.