Uses of Enum
com.chargebee.models.Order.OrderLineItem.Status
Packages that use Order.OrderLineItem.Status
-
Uses of Order.OrderLineItem.Status in com.chargebee.models
Methods in com.chargebee.models that return Order.OrderLineItem.StatusModifier and TypeMethodDescriptionOrder.OrderLineItem.status()static Order.OrderLineItem.StatusReturns the enum constant of this type with the specified name.static Order.OrderLineItem.Status[]Order.OrderLineItem.Status.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.chargebee.models with parameters of type Order.OrderLineItem.StatusModifier and TypeMethodDescriptionOrder.UpdateRequest.orderLineItemStatus(int index, Order.OrderLineItem.Status orderLineItemStatus)