Uses of Enum
com.chargebee.models.Order.Status
Packages that use Order.Status
-
Uses of Order.Status in com.chargebee.models
Methods in com.chargebee.models that return Order.StatusModifier and TypeMethodDescriptionOrder.status()static Order.StatusReturns the enum constant of this type with the specified name.static Order.Status[]Order.Status.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.chargebee.models that return types with arguments of type Order.StatusModifier and TypeMethodDescriptionExport.OrdersRequest.orderStatus()Order.OrderListRequest.status()Methods in com.chargebee.models with parameters of type Order.StatusModifier and TypeMethodDescriptionOrder.CreateRequest.status(Order.Status status) Order.ImportOrderRequest.status(Order.Status status) Order.UpdateRequest.status(Order.Status status)