Uses of Enum
com.chargebee.models.Plan.AddonApplicability
Packages that use Plan.AddonApplicability
-
Uses of Plan.AddonApplicability in com.chargebee.models
Methods in com.chargebee.models that return Plan.AddonApplicabilityModifier and TypeMethodDescriptionPlan.addonApplicability()static Plan.AddonApplicabilityReturns the enum constant of this type with the specified name.static Plan.AddonApplicability[]Plan.AddonApplicability.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.chargebee.models that return types with arguments of type Plan.AddonApplicabilityModifier and TypeMethodDescriptionPlan.PlanListRequest.addonApplicability()Export.PlansRequest.planAddonApplicability()Methods in com.chargebee.models with parameters of type Plan.AddonApplicabilityModifier and TypeMethodDescriptionPlan.CreateRequest.addonApplicability(Plan.AddonApplicability addonApplicability) Plan.UpdateRequest.addonApplicability(Plan.AddonApplicability addonApplicability)