Uses of Enum
com.chargebee.models.Plan.ChargeModel
Packages that use Plan.ChargeModel
-
Uses of Plan.ChargeModel in com.chargebee.models
Methods in com.chargebee.models that return Plan.ChargeModelModifier and TypeMethodDescriptionPlan.chargeModel()Deprecated.static Plan.ChargeModelDeprecated.Returns the enum constant of this type with the specified name.static Plan.ChargeModel[]Plan.ChargeModel.values()Deprecated.Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.chargebee.models that return types with arguments of type Plan.ChargeModelMethods in com.chargebee.models with parameters of type Plan.ChargeModelModifier and TypeMethodDescriptionPlan.CreateRequest.chargeModel(Plan.ChargeModel chargeModel) Deprecated.Plan.UpdateRequest.chargeModel(Plan.ChargeModel chargeModel) Deprecated.