Uses of Enum
com.chargebee.models.Rule.Status
Packages that use Rule.Status
-
Uses of Rule.Status in com.chargebee.models
Methods in com.chargebee.models that return Rule.StatusModifier and TypeMethodDescriptionRule.status()static Rule.StatusReturns the enum constant of this type with the specified name.static Rule.Status[]Rule.Status.values()Returns an array containing the constants of this enum type, in the order they are declared.