Uses of Enum
com.chargebee.models.TimeMachine.TimeTravelStatus
Packages that use TimeMachine.TimeTravelStatus
-
Uses of TimeMachine.TimeTravelStatus in com.chargebee.models
Methods in com.chargebee.models that return TimeMachine.TimeTravelStatusModifier and TypeMethodDescriptionTimeMachine.timeTravelStatus()static TimeMachine.TimeTravelStatusReturns the enum constant of this type with the specified name.static TimeMachine.TimeTravelStatus[]TimeMachine.TimeTravelStatus.values()Returns an array containing the constants of this enum type, in the order they are declared.