Uses of Enum
com.chargebee.models.Transaction.AuthorizationReason
Packages that use Transaction.AuthorizationReason
-
Uses of Transaction.AuthorizationReason in com.chargebee.models
Methods in com.chargebee.models that return Transaction.AuthorizationReasonModifier and TypeMethodDescriptionInvoice.ReferenceTransaction.authorizationReason()Transaction.authorizationReason()Returns the enum constant of this type with the specified name.static Transaction.AuthorizationReason[]Transaction.AuthorizationReason.values()Returns an array containing the constants of this enum type, in the order they are declared.