Uses of Enum
com.chargebee.models.Transaction.Status
Packages that use Transaction.Status
-
Uses of Transaction.Status in com.chargebee.models
Methods in com.chargebee.models that return Transaction.StatusModifier and TypeMethodDescriptionTransaction.status()CreditNote.LinkedRefund.txnStatus()Invoice.DunningAttempt.txnStatus()Invoice.LinkedPayment.txnStatus()Invoice.ReferenceTransaction.txnStatus()Transaction.LinkedRefund.txnStatus()static Transaction.StatusReturns the enum constant of this type with the specified name.static Transaction.Status[]Transaction.Status.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.chargebee.models that return types with arguments of type Transaction.StatusModifier and TypeMethodDescriptionTransaction.TransactionListRequest.status()Export.TransactionsRequest.transactionStatus()Methods in com.chargebee.models with parameters of type Transaction.StatusModifier and TypeMethodDescriptionTransaction.ReconcileRequest.status(Transaction.Status status) Invoice.RecordPaymentRequest.transactionStatus(Transaction.Status transactionStatus)