Enum Layout

java.lang.Object
java.lang.Enum<Layout>
com.chargebee.models.enums.Layout
All Implemented Interfaces:
Serializable, Comparable<Layout>, java.lang.constant.Constable

public enum Layout extends Enum<Layout>
  • Enum Constant Details

    • IN_APP

      public static final Layout IN_APP
    • FULL_PAGE

      public static final Layout FULL_PAGE
    • _UNKNOWN

      public static final Layout _UNKNOWN
  • Method Details

    • values

      public static Layout[] values()
      Returns an array containing the constants of this enum type, in the order they are declared.
      Returns:
      an array containing the constants of this enum type, in the order they are declared
    • valueOf

      public static Layout valueOf(String name)
      Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum type has no constant with the specified name
      NullPointerException - if the argument is null