Enum Source

java.lang.Object
java.lang.Enum<Source>
com.chargebee.models.enums.Source
All Implemented Interfaces:
Serializable, Comparable<Source>, java.lang.constant.Constable

public enum Source extends Enum<Source>
  • Enum Constant Details

    • ADMIN_CONSOLE

      public static final Source ADMIN_CONSOLE
    • API

      public static final Source API
    • BULK_OPERATION

      public static final Source BULK_OPERATION
    • SCHEDULED_JOB

      public static final Source SCHEDULED_JOB
    • HOSTED_PAGE

      public static final Source HOSTED_PAGE
    • PORTAL

      public static final Source PORTAL
    • SYSTEM

      public static final Source SYSTEM
    • NONE

      public static final Source NONE
    • JS_API

      public static final Source JS_API
    • MIGRATION

      public static final Source MIGRATION
    • EXTERNAL_SERVICE

      public static final Source EXTERNAL_SERVICE
    • _UNKNOWN

      public static final Source _UNKNOWN
  • Method Details

    • values

      public static Source[] values()
      Returns an array containing the constants of this enum type, in the order they are declared.
      Returns:
      an array containing the constants of this enum type, in the order they are declared
    • valueOf

      public static Source valueOf(String name)
      Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum type has no constant with the specified name
      NullPointerException - if the argument is null