Uses of Enum
com.chargebee.models.enums.EntityCode
Packages that use EntityCode
-
Uses of EntityCode in com.chargebee.models
Methods in com.chargebee.models that return EntityCodeMethods in com.chargebee.models with parameters of type EntityCodeModifier and TypeMethodDescriptionEstimate.CreateSubItemEstimateRequest.customerEntityCode(EntityCode customerEntityCode) Estimate.CreateSubscriptionRequest.customerEntityCode(EntityCode customerEntityCode) Purchase.EstimateRequest.customerEntityCode(EntityCode customerEntityCode) Subscription.CreateRequest.customerEntityCode(EntityCode customerEntityCode) Subscription.ImportSubscriptionRequest.customerEntityCode(EntityCode customerEntityCode) Customer.CreateRequest.entityCode(EntityCode entityCode) Customer.UpdateRequest.entityCode(EntityCode entityCode) -
Uses of EntityCode in com.chargebee.models.enums
Methods in com.chargebee.models.enums that return EntityCodeModifier and TypeMethodDescriptionstatic EntityCodeReturns the enum constant of this type with the specified name.static EntityCode[]EntityCode.values()Returns an array containing the constants of this enum type, in the order they are declared.