Uses of Enum
com.chargebee.models.enums.NotifyReferralSystem
Packages that use NotifyReferralSystem
-
Uses of NotifyReferralSystem in com.chargebee.models
Methods in com.chargebee.models that return NotifyReferralSystem -
Uses of NotifyReferralSystem in com.chargebee.models.enums
Methods in com.chargebee.models.enums that return NotifyReferralSystemModifier and TypeMethodDescriptionstatic NotifyReferralSystemReturns the enum constant of this type with the specified name.static NotifyReferralSystem[]NotifyReferralSystem.values()Returns an array containing the constants of this enum type, in the order they are declared.