Uses of Enum
com.chargebee.models.enums.ReferralSystem
Packages that use ReferralSystem
-
Uses of ReferralSystem in com.chargebee.models
Methods in com.chargebee.models that return ReferralSystemModifier and TypeMethodDescriptionCustomer.ReferralUrl.referralSystem()Subscription.ReferralInfo.referralSystem() -
Uses of ReferralSystem in com.chargebee.models.enums
Methods in com.chargebee.models.enums that return ReferralSystemModifier and TypeMethodDescriptionstatic ReferralSystemReturns the enum constant of this type with the specified name.static ReferralSystem[]ReferralSystem.values()Returns an array containing the constants of this enum type, in the order they are declared.