Package com.chargebee.v4.client.request
Class RequestContext
java.lang.Object
com.chargebee.v4.client.request.RequestContext
Context for request execution that holds headers and other request-specific data.
Used internally to pass header information between service layers.
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionGet all headers as an immutable map.merge(RequestContext other) Create a new RequestContext with merged headers.
-
Constructor Details
-
RequestContext
public RequestContext() -
RequestContext
-
-
Method Details
-
header
-
headers
-
getHeaders
Get all headers as an immutable map. -
merge
Create a new RequestContext with merged headers. Operation headers override client headers.
-