Class RequestOptions

java.lang.Object
com.chargebee.v4.client.request.RequestOptions

public final class RequestOptions extends Object
Immutable request options for per-request configuration. Supports headers and can be extended for timeouts, retries, API versions, etc.
  • Method Details

    • empty

      public static RequestOptions empty()
    • builder

      public static RequestOptions.Builder builder()
    • withHeader

      public RequestOptions withHeader(String key, String value)
    • withHeaders

      public RequestOptions withHeaders(Map<String,String> newHeaders)
    • getHeaders

      public Map<String,String> getHeaders()
    • getIdempotencyKey

      public String getIdempotencyKey()
      Get the idempotency key for this request, if set.
      Returns:
      the idempotency key, or null if not set
    • getMaxNetworkRetries

      public Integer getMaxNetworkRetries()
    • getRetryEnabled

      public Boolean getRetryEnabled()
    • getRetryBaseDelayMs

      public Integer getRetryBaseDelayMs()
    • getRetryOnStatus

      public Set<Integer> getRetryOnStatus()
    • getConnectTimeoutMs

      public Integer getConnectTimeoutMs()
    • getReadTimeoutMs

      public Integer getReadTimeoutMs()
    • getFollowRedirects

      public Boolean getFollowRedirects()
    • getGzipCompression

      public Boolean getGzipCompression()
    • getRequestLogger

      public RequestLogger getRequestLogger()