Enum Class BadRequestApiErrorCode

java.lang.Object
java.lang.Enum<BadRequestApiErrorCode>
com.chargebee.v4.exceptions.codes.BadRequestApiErrorCode
All Implemented Interfaces:
ApiErrorCode, Serializable, Comparable<BadRequestApiErrorCode>, Constable

public enum BadRequestApiErrorCode extends Enum<BadRequestApiErrorCode> implements ApiErrorCode
API error codes for HTTP 400 responses
  • Enum Constant Details

    • PAYMENT_INTENT_INVALID_AMOUNT

      public static final BadRequestApiErrorCode PAYMENT_INTENT_INVALID_AMOUNT
      API error code: payment_intent_invalid_amount
    • CONFIGURATION_INCOMPATIBLE

      public static final BadRequestApiErrorCode CONFIGURATION_INCOMPATIBLE
      API error code: configuration_incompatible
    • PAYMENT_INTENT_INVALID

      public static final BadRequestApiErrorCode PAYMENT_INTENT_INVALID
      API error code: payment_intent_invalid
    • INVALID_REQUEST

      public static final BadRequestApiErrorCode INVALID_REQUEST
      API error code: invalid_request
    • PAYMENT_METHOD_VERIFICATION_FAILED

      public static final BadRequestApiErrorCode PAYMENT_METHOD_VERIFICATION_FAILED
      API error code: payment_method_verification_failed
    • PAYMENT_PROCESSING_FAILED

      public static final BadRequestApiErrorCode PAYMENT_PROCESSING_FAILED
      API error code: payment_processing_failed
    • RESOURCE_LIMIT_EXHAUSTED

      public static final BadRequestApiErrorCode RESOURCE_LIMIT_EXHAUSTED
      API error code: resource_limit_exhausted
    • DUPLICATE_ENTRY

      public static final BadRequestApiErrorCode DUPLICATE_ENTRY
      API error code: duplicate_entry
    • PARAM_WRONG_VALUE

      public static final BadRequestApiErrorCode PARAM_WRONG_VALUE
      API error code: param_wrong_value
    • PAYMENT_METHOD_NOT_PRESENT

      public static final BadRequestApiErrorCode PAYMENT_METHOD_NOT_PRESENT
      API error code: payment_method_not_present
    • RESOURCE_LIMIT_EXCEEDED

      public static final BadRequestApiErrorCode RESOURCE_LIMIT_EXCEEDED
      API error code: resource_limit_exceeded
    • PAYMENT_GATEWAY_CURRENCY_INCOMPATIBLE

      public static final BadRequestApiErrorCode PAYMENT_GATEWAY_CURRENCY_INCOMPATIBLE
      API error code: payment_gateway_currency_incompatible
    • _UNKNOWN

      public static final BadRequestApiErrorCode _UNKNOWN
      Represents an unknown or unrecognized error code. This allows forward compatibility when new error codes are added.
  • Method Details

    • values

      public static BadRequestApiErrorCode[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static BadRequestApiErrorCode valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null
    • getValue

      public String getValue()
      Get the string value of this error code as returned by the API.
      Specified by:
      getValue in interface ApiErrorCode
      Returns:
      the API string value, or null for _UNKNOWN
    • fromString

      public static BadRequestApiErrorCode fromString(String value)
      Convert an API string value to the corresponding enum constant. Returns _UNKNOWN for unrecognized values to ensure forward compatibility.
      Parameters:
      value - the API string value
      Returns:
      the corresponding enum constant, or _UNKNOWN if not recognized
    • isKnown

      public boolean isKnown()
      Check if this error code is a known (non-unknown) value.
      Specified by:
      isKnown in interface ApiErrorCode
      Returns:
      true if this is a recognized error code