Enum Class ServiceUnavailableApiErrorCode
java.lang.Object
java.lang.Enum<ServiceUnavailableApiErrorCode>
com.chargebee.v4.exceptions.codes.ServiceUnavailableApiErrorCode
- All Implemented Interfaces:
ApiErrorCode,Serializable,Comparable<ServiceUnavailableApiErrorCode>,Constable
public enum ServiceUnavailableApiErrorCode
extends Enum<ServiceUnavailableApiErrorCode>
implements ApiErrorCode
API error codes for HTTP 503 responses
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionRepresents an unknown or unrecognized error code.API error code: db_connection_failureAPI error code: internal_temporary_errorAPI error code: site_not_readyAPI error code: site_read_only_mode -
Method Summary
Modifier and TypeMethodDescriptionfromString(String value) Convert an API string value to the corresponding enum constant.getValue()Get the string value of this error code as returned by the API.booleanisKnown()Check if this error code is a known (non-unknown) value.Returns the enum constant of this class with the specified name.static ServiceUnavailableApiErrorCode[]values()Returns an array containing the constants of this enum class, in the order they are declared.Methods inherited from class java.lang.Enum
clone, compareTo, describeConstable, equals, finalize, getDeclaringClass, hashCode, name, ordinal, toString, valueOfMethods inherited from interface com.chargebee.v4.exceptions.codes.ApiErrorCode
name
-
Enum Constant Details
-
DB_CONNECTION_FAILURE
API error code: db_connection_failure -
SITE_READ_ONLY_MODE
API error code: site_read_only_mode -
SITE_NOT_READY
API error code: site_not_ready -
INTERNAL_TEMPORARY_ERROR
API error code: internal_temporary_error -
_UNKNOWN
Represents an unknown or unrecognized error code. This allows forward compatibility when new error codes are added.
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getValue
Get the string value of this error code as returned by the API.- Specified by:
getValuein interfaceApiErrorCode- Returns:
- the API string value, or null for _UNKNOWN
-
fromString
Convert an API string value to the corresponding enum constant. Returns _UNKNOWN for unrecognized values to ensure forward compatibility.- Parameters:
value- the API string value- Returns:
- the corresponding enum constant, or _UNKNOWN if not recognized
-
isKnown
public boolean isKnown()Check if this error code is a known (non-unknown) value.- Specified by:
isKnownin interfaceApiErrorCode- Returns:
- true if this is a recognized error code
-