Class Addon

java.lang.Object
com.chargebee.v4.models.addon.Addon

public class Addon extends Object
  • Constructor Details

    • Addon

      public Addon()
  • Method Details

    • getId

      public String getId()
    • getName

      public String getName()
    • getInvoiceName

      public String getInvoiceName()
    • getDescription

      public String getDescription()
    • getPricingModel

      public Addon.PricingModel getPricingModel()
    • getType

      @Deprecated public Addon.Type getType()
      Deprecated.
    • getChargeType

      public Addon.ChargeType getChargeType()
    • getPrice

      public Long getPrice()
    • getCurrencyCode

      public String getCurrencyCode()
    • getPeriod

      public Integer getPeriod()
    • getPeriodUnit

      public Addon.PeriodUnit getPeriodUnit()
    • getUnit

      public String getUnit()
    • getStatus

      public Addon.Status getStatus()
    • getArchivedAt

      public Timestamp getArchivedAt()
    • getEnabledInPortal

      public Boolean getEnabledInPortal()
    • getTaxCode

      public String getTaxCode()
    • getHsnCode

      public String getHsnCode()
    • getTaxjarProductCode

      public String getTaxjarProductCode()
    • getAvalaraSaleType

      public Addon.AvalaraSaleType getAvalaraSaleType()
    • getAvalaraTransactionType

      public Integer getAvalaraTransactionType()
    • getAvalaraServiceType

      public Integer getAvalaraServiceType()
    • getSku

      public String getSku()
    • getAccountingCode

      public String getAccountingCode()
    • getAccountingCategory1

      public String getAccountingCategory1()
    • getAccountingCategory2

      public String getAccountingCategory2()
    • getAccountingCategory3

      public String getAccountingCategory3()
    • getAccountingCategory4

      public String getAccountingCategory4()
    • getIsShippable

      public Boolean getIsShippable()
    • getShippingFrequencyPeriod

      public Integer getShippingFrequencyPeriod()
    • getShippingFrequencyPeriodUnit

      public Addon.ShippingFrequencyPeriodUnit getShippingFrequencyPeriodUnit()
    • getResourceVersion

      public Long getResourceVersion()
    • getUpdatedAt

      public Timestamp getUpdatedAt()
    • getPriceInDecimal

      public String getPriceInDecimal()
    • getIncludedInMrr

      public Boolean getIncludedInMrr()
    • getChannel

      public Addon.Channel getChannel()
    • getProrationType

      public Addon.ProrationType getProrationType()
    • getInvoiceNotes

      public String getInvoiceNotes()
    • getTaxable

      public Boolean getTaxable()
    • getTaxProfileId

      public String getTaxProfileId()
    • getMetaData

      public Map<String,Object> getMetaData()
    • getShowDescriptionInInvoices

      public Boolean getShowDescriptionInInvoices()
    • getShowDescriptionInQuotes

      public Boolean getShowDescriptionInQuotes()
    • getTiers

      public List<Addon.Tiers> getTiers()
    • getTaxProvidersFields

      public List<Addon.TaxProvidersFields> getTaxProvidersFields()
    • getCustomFields

      public Map<String,String> getCustomFields()
      Returns a map of custom fields. Custom fields are dynamic properties that follow the pattern cf_* (e.g., cf_custom_field_name).
      Returns:
      map containing all custom fields
    • getCustomField

      public String getCustomField(String fieldName)
      Returns the value of a specific custom field.
      Parameters:
      fieldName - the name of the custom field (e.g., "cf_custom_field_name")
      Returns:
      the value of the custom field, or null if not present
    • fromJson

      public static Addon fromJson(String json)
    • fromJson

      public static Addon fromJson(Map<String,Object> map)
    • fromJson

      public static Addon fromJson(com.google.gson.JsonObject jsonObj)
    • toString

      public String toString()
      Overrides:
      toString in class Object
    • equals

      public boolean equals(Object o)
      Overrides:
      equals in class Object
    • hashCode

      public int hashCode()
      Overrides:
      hashCode in class Object