Class CreditNote
java.lang.Object
com.chargebee.v4.models.creditNote.CreditNote
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic classstatic classstatic enumstatic classstatic classstatic classstatic classstatic classstatic classstatic classstatic classstatic enumstatic enumstatic classstatic classstatic enumstatic classstatic classstatic enum -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanstatic CreditNotegetCustomField(String fieldName) Returns the value of a specific custom field.Returns a map of custom fields.getDate()getId()getTaxes()getTotal()getType()inthashCode()toString()
-
Constructor Details
-
CreditNote
public CreditNote()
-
-
Method Details
-
getId
-
getCustomerId
-
getSubscriptionId
-
getReferenceInvoiceId
-
getType
-
getReasonCode
-
getStatus
-
getVatNumber
-
getDate
-
getPriceType
-
getCurrencyCode
-
getTotal
-
getAmountAllocated
-
getAmountRefunded
-
getAmountAvailable
-
getRefundedAt
-
getVoidedAt
-
getGeneratedAt
-
getResourceVersion
-
getUpdatedAt
-
getChannel
-
getLineItemsNextOffset
-
getSubTotal
-
getSubTotalInLocalCurrency
-
getTotalInLocalCurrency
-
getLocalCurrencyCode
-
getRoundOffAmount
-
getFractionalCorrection
-
getDeleted
-
getTaxCategory
-
getLocalCurrencyExchangeRate
-
getCreateReasonCode
-
getVatNumberPrefix
-
getBusinessEntityId
-
getLineItems
-
getLineItemTiers
-
getLineItemDiscounts
-
getLineItemTaxes
-
getLineItemAddresses
-
getDiscounts
-
getTaxes
-
getTaxOrigin
-
getLinkedRefunds
-
getAllocations
-
getShippingAddress
-
getBillingAddress
-
getEinvoice
-
getSiteDetailsAtCreation
-
getCustomFields
Returns a map of custom fields. Custom fields are dynamic properties that follow the pattern cf_* (e.g., cf_custom_field_name).- Returns:
- map containing all custom fields
-
getCustomField
Returns the value of a specific custom field.- Parameters:
fieldName- the name of the custom field (e.g., "cf_custom_field_name")- Returns:
- the value of the custom field, or null if not present
-
fromJson
-
toString
-
equals
-
hashCode
public int hashCode()
-