Enum Class OrderCreateRefundableCreditNoteParams.CreditNoteParams.ReasonCode
java.lang.Object
java.lang.Enum<OrderCreateRefundableCreditNoteParams.CreditNoteParams.ReasonCode>
com.chargebee.v4.models.order.params.OrderCreateRefundableCreditNoteParams.CreditNoteParams.ReasonCode
- All Implemented Interfaces:
Serializable,Comparable<OrderCreateRefundableCreditNoteParams.CreditNoteParams.ReasonCode>,Constable
- Enclosing class:
- OrderCreateRefundableCreditNoteParams.CreditNoteParams
public static enum OrderCreateRefundableCreditNoteParams.CreditNoteParams.ReasonCode
extends Enum<OrderCreateRefundableCreditNoteParams.CreditNoteParams.ReasonCode>
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionAn enum member indicating that ReasonCode was instantiated with an unknown value. -
Method Summary
Modifier and TypeMethodDescriptionfromString(String value) getValue()Returns the enum constant of this class with the specified name.values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
WRITE_OFF
-
SUBSCRIPTION_CHANGE
public static final OrderCreateRefundableCreditNoteParams.CreditNoteParams.ReasonCode SUBSCRIPTION_CHANGE -
SUBSCRIPTION_CANCELLATION
public static final OrderCreateRefundableCreditNoteParams.CreditNoteParams.ReasonCode SUBSCRIPTION_CANCELLATION -
SUBSCRIPTION_PAUSE
public static final OrderCreateRefundableCreditNoteParams.CreditNoteParams.ReasonCode SUBSCRIPTION_PAUSE -
CHARGEBACK
-
PRODUCT_UNSATISFACTORY
public static final OrderCreateRefundableCreditNoteParams.CreditNoteParams.ReasonCode PRODUCT_UNSATISFACTORY -
SERVICE_UNSATISFACTORY
public static final OrderCreateRefundableCreditNoteParams.CreditNoteParams.ReasonCode SERVICE_UNSATISFACTORY -
ORDER_CHANGE
-
ORDER_CANCELLATION
public static final OrderCreateRefundableCreditNoteParams.CreditNoteParams.ReasonCode ORDER_CANCELLATION -
WAIVER
-
OTHER
-
FRAUDULENT
-
_UNKNOWN
An enum member indicating that ReasonCode was instantiated with an unknown value.
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
public static OrderCreateRefundableCreditNoteParams.CreditNoteParams.ReasonCode valueOf(String name) Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getValue
-
fromString
public static OrderCreateRefundableCreditNoteParams.CreditNoteParams.ReasonCode fromString(String value)
-