Enum Class Usage.Source

java.lang.Object
java.lang.Enum<Usage.Source>
com.chargebee.v4.models.usage.Usage.Source
All Implemented Interfaces:
Serializable, Comparable<Usage.Source>, Constable
Enclosing class:
Usage

public static enum Usage.Source extends Enum<Usage.Source>
  • Enum Constant Details

    • ADMIN_CONSOLE

      public static final Usage.Source ADMIN_CONSOLE
    • API

      public static final Usage.Source API
    • BULK_OPERATION

      public static final Usage.Source BULK_OPERATION
    • _UNKNOWN

      public static final Usage.Source _UNKNOWN
      An enum member indicating that Source was instantiated with an unknown value.
  • Method Details

    • values

      public static Usage.Source[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static Usage.Source valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null
    • getValue

      public String getValue()
    • fromString

      public static Usage.Source fromString(String value)