Package com.chargebee.v4.services
Class ExportService
-
Field Summary
Fields inherited from class com.chargebee.v4.services.BaseService
client, options -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionaddons(ExportAddonsParams params) addonsAsync(ExportAddonsParams params) Async variant of addons for export with params.Async variant of attachedItems for export with params.coupons(ExportCouponsParams params) couponsAsync(ExportCouponsParams params) Async variant of coupons for export with params.creditNotes(ExportCreditNotesParams params) Async variant of creditNotes for export with params.customers(ExportCustomersParams params) customersAsync(ExportCustomersParams params) Async variant of customers for export with params.Async variant of deferredRevenue for export with params.Async variant of differentialPrices for export with params.invoices(ExportInvoicesParams params) invoicesAsync(ExportInvoicesParams params) Async variant of invoices for export with params.itemFamilies(ExportItemFamiliesParams params) Async variant of itemFamilies for export with params.itemPrices(ExportItemPricesParams params) Async variant of itemPrices for export with params.items(ExportItemsParams params) itemsAsync(ExportItemsParams params) Async variant of items for export with params.orders(ExportOrdersParams params) ordersAsync(ExportOrdersParams params) Async variant of orders for export with params.plans(ExportPlansParams params) plansAsync(ExportPlansParams params) Async variant of plans for export with params.Async variant of priceVariants for export with params.retrieveAsync(String exportId) Async variant of retrieve for export without params.Async variant of revenueRecognition for export with params.Async variant of subscriptions for export with params.transactions(ExportTransactionsParams params) Async variant of transactions for export with params.waitForExportCompletion(Export export) Waits for an export operation to complete by polling its status.withOptions(RequestOptions options) Apply per-request options for this service instance.Methods inherited from class com.chargebee.v4.services.BaseService
buildPathWithParams, clientForBuilders, clientWithOptions, get, getAsync, getMergedHeaders, getWithSubDomain, getWithSubDomainAsync, header, headers, options, parseResponse, post, postAsync, postJson, postJsonAsync, postJsonWithSubDomain, postJsonWithSubDomainAsync, postWithSubDomain, postWithSubDomainAsync
-
Constructor Details
-
ExportService
-
-
Method Details
-
withOptions
Apply per-request options for this service instance. Users can chain .withOptions or .options to set headers and other options.- Overrides:
withOptionsin classBaseService<ExportService>
-
customers
- Throws:
ChargebeeException
-
customersAsync
Async variant of customers for export with params. -
attachedItems
public ExportAttachedItemsResponse attachedItems(ExportAttachedItemsParams params) throws ChargebeeException - Throws:
ChargebeeException
-
attachedItemsAsync
public CompletableFuture<ExportAttachedItemsResponse> attachedItemsAsync(ExportAttachedItemsParams params) Async variant of attachedItems for export with params. -
transactions
public ExportTransactionsResponse transactions(ExportTransactionsParams params) throws ChargebeeException - Throws:
ChargebeeException
-
transactionsAsync
public CompletableFuture<ExportTransactionsResponse> transactionsAsync(ExportTransactionsParams params) Async variant of transactions for export with params. -
differentialPrices
public ExportDifferentialPricesResponse differentialPrices(ExportDifferentialPricesParams params) throws ChargebeeException - Throws:
ChargebeeException
-
differentialPricesAsync
public CompletableFuture<ExportDifferentialPricesResponse> differentialPricesAsync(ExportDifferentialPricesParams params) Async variant of differentialPrices for export with params. -
itemFamilies
public ExportItemFamiliesResponse itemFamilies(ExportItemFamiliesParams params) throws ChargebeeException - Throws:
ChargebeeException
-
itemFamiliesAsync
public CompletableFuture<ExportItemFamiliesResponse> itemFamiliesAsync(ExportItemFamiliesParams params) Async variant of itemFamilies for export with params. -
invoices
- Throws:
ChargebeeException
-
invoicesAsync
Async variant of invoices for export with params. -
retrieve
- Throws:
ChargebeeException
-
retrieveAsync
Async variant of retrieve for export without params. -
priceVariants
public ExportPriceVariantsResponse priceVariants(ExportPriceVariantsParams params) throws ChargebeeException - Throws:
ChargebeeException
-
priceVariantsAsync
public CompletableFuture<ExportPriceVariantsResponse> priceVariantsAsync(ExportPriceVariantsParams params) Async variant of priceVariants for export with params. -
items
- Throws:
ChargebeeException
-
itemsAsync
Async variant of items for export with params. -
deferredRevenue
public ExportDeferredRevenueResponse deferredRevenue(ExportDeferredRevenueParams params) throws ChargebeeException - Throws:
ChargebeeException
-
deferredRevenueAsync
public CompletableFuture<ExportDeferredRevenueResponse> deferredRevenueAsync(ExportDeferredRevenueParams params) Async variant of deferredRevenue for export with params. -
revenueRecognition
public ExportRevenueRecognitionResponse revenueRecognition(ExportRevenueRecognitionParams params) throws ChargebeeException - Throws:
ChargebeeException
-
revenueRecognitionAsync
public CompletableFuture<ExportRevenueRecognitionResponse> revenueRecognitionAsync(ExportRevenueRecognitionParams params) Async variant of revenueRecognition for export with params. -
creditNotes
public ExportCreditNotesResponse creditNotes(ExportCreditNotesParams params) throws ChargebeeException - Throws:
ChargebeeException
-
creditNotesAsync
public CompletableFuture<ExportCreditNotesResponse> creditNotesAsync(ExportCreditNotesParams params) Async variant of creditNotes for export with params. -
coupons
- Throws:
ChargebeeException
-
couponsAsync
Async variant of coupons for export with params. -
orders
- Throws:
ChargebeeException
-
ordersAsync
Async variant of orders for export with params. -
itemPrices
- Throws:
ChargebeeException
-
itemPricesAsync
Async variant of itemPrices for export with params. -
subscriptions
public ExportSubscriptionsResponse subscriptions(ExportSubscriptionsParams params) throws ChargebeeException - Throws:
ChargebeeException
-
subscriptionsAsync
public CompletableFuture<ExportSubscriptionsResponse> subscriptionsAsync(ExportSubscriptionsParams params) Async variant of subscriptions for export with params. -
addons
- Throws:
ChargebeeException
-
addonsAsync
Async variant of addons for export with params. -
plans
- Throws:
ChargebeeException
-
plansAsync
Async variant of plans for export with params. -
waitForExportCompletion
public Export waitForExportCompletion(Export export) throws ChargebeeException, InterruptedException Waits for an export operation to complete by polling its status. Polls every 10 seconds (configurable via cb.java.export.sleep.millis system property).- Parameters:
export- The export to wait for (must have a valid ID)- Returns:
- The completed Export object with COMPLETED or FAILED status
- Throws:
ChargebeeException- if API call fails during pollingRuntimeException- if export takes too long (over 50 polling attempts)InterruptedException- if thread is interrupted while waiting
-