Package com.chargebee.v4.services
Class TimeMachineService
java.lang.Object
com.chargebee.v4.services.BaseService<TimeMachineService>
com.chargebee.v4.services.TimeMachineService
-
Field Summary
Fields inherited from class com.chargebee.v4.services.BaseService
client, options -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionretrieveAsync(String timeMachineName) Async variant of retrieve for timeMachine without params.startAfresh(String timeMachineName) startAfresh(String timeMachineName, TimeMachineStartAfreshParams params) startAfreshAsync(String timeMachineName) Async variant of startAfresh for timeMachine without params.startAfreshAsync(String timeMachineName, TimeMachineStartAfreshParams params) Async variant of startAfresh for timeMachine with params.travelForward(String timeMachineName) travelForward(String timeMachineName, TimeMachineTravelForwardParams params) travelForwardAsync(String timeMachineName) Async variant of travelForward for timeMachine without params.travelForwardAsync(String timeMachineName, TimeMachineTravelForwardParams params) Async variant of travelForward for timeMachine with params.waitForTimeTravelCompletion(TimeMachine timeMachine) Waits for time travel operation to complete.waitForTimeTravelCompletion(String timeMachineName) Waits for time travel operation to complete.withOptions(RequestOptions options) Apply per-request options for this service instance.Methods inherited from class com.chargebee.v4.services.BaseService
buildPathWithParams, clientForBuilders, clientWithOptions, get, getAsync, getMergedHeaders, getWithSubDomain, getWithSubDomainAsync, header, headers, options, parseResponse, post, postAsync, postJson, postJsonAsync, postJsonWithSubDomain, postJsonWithSubDomainAsync, postWithSubDomain, postWithSubDomainAsync
-
Constructor Details
-
TimeMachineService
-
-
Method Details
-
withOptions
Apply per-request options for this service instance. Users can chain .withOptions or .options to set headers and other options.- Overrides:
withOptionsin classBaseService<TimeMachineService>
-
retrieve
- Throws:
ChargebeeException
-
retrieveAsync
Async variant of retrieve for timeMachine without params. -
travelForward
public TimeMachineTravelForwardResponse travelForward(String timeMachineName, TimeMachineTravelForwardParams params) throws ChargebeeException - Throws:
ChargebeeException
-
travelForwardAsync
public CompletableFuture<TimeMachineTravelForwardResponse> travelForwardAsync(String timeMachineName, TimeMachineTravelForwardParams params) Async variant of travelForward for timeMachine with params. -
travelForward
public TimeMachineTravelForwardResponse travelForward(String timeMachineName) throws ChargebeeException - Throws:
ChargebeeException
-
travelForwardAsync
public CompletableFuture<TimeMachineTravelForwardResponse> travelForwardAsync(String timeMachineName) Async variant of travelForward for timeMachine without params. -
startAfresh
public TimeMachineStartAfreshResponse startAfresh(String timeMachineName, TimeMachineStartAfreshParams params) throws ChargebeeException - Throws:
ChargebeeException
-
startAfreshAsync
public CompletableFuture<TimeMachineStartAfreshResponse> startAfreshAsync(String timeMachineName, TimeMachineStartAfreshParams params) Async variant of startAfresh for timeMachine with params. -
startAfresh
- Throws:
ChargebeeException
-
startAfreshAsync
Async variant of startAfresh for timeMachine without params. -
waitForTimeTravelCompletion
public TimeMachine waitForTimeTravelCompletion(TimeMachine timeMachine) throws ChargebeeException, InterruptedException Waits for time travel operation to complete. Polls the API until the status changes from IN_PROGRESS.- Parameters:
timeMachine- The TimeMachine instance to wait for- Returns:
- The updated TimeMachine with final status
- Throws:
ChargebeeException- if the API call failsInterruptedException- if the thread is interrupted while waitingRuntimeException- if time travel takes too long or ends in invalid stateOperationFailedException- if time travel fails
-
waitForTimeTravelCompletion
public TimeMachine waitForTimeTravelCompletion(String timeMachineName) throws ChargebeeException, InterruptedException Waits for time travel operation to complete. Polls the API until the status changes from IN_PROGRESS.- Parameters:
timeMachineName- The name of the TimeMachine to wait for- Returns:
- The updated TimeMachine with final status
- Throws:
ChargebeeException- if the API call failsInterruptedException- if the thread is interrupted while waitingRuntimeException- if time travel takes too long or ends in invalid stateOperationFailedException- if time travel fails
-