Serialized Form
-
Package com.chargebee.v4.exceptions
-
Exception com.chargebee.v4.exceptions.APIException
class APIException extends HttpException implements Serializable-
Serialized Fields
-
apiErrorCode
ApiErrorCode apiErrorCode
A more specific error code as a strongly-typed enum. Implements ApiErrorCode interface for type-safe error handling. -
apiErrorCodeRaw
String apiErrorCodeRaw
The raw API error code string as returned by the API. Example: "duplicate_entry", "payment_processing_failed", "resource_not_found" -
errorCauseId
String errorCauseId
Chargebee-defined code for standardizing errors across different gateway services. Helps in consistent error handling across payment gateways. May be null if not applicable. -
errorType
ErrorType errorType
The error type as a strongly-typed enum. Groups errors based on the error handling routine required. -
jsonResponse
String jsonResponse
The full JSON response for debugging or extracting additional details. -
params
List<String> params
The parameter name(s) if the error is due to specific parameter(s). Empty list if error is not parameter-specific. -
type
String type
The raw error type string as returned by the API. Values: "payment", "invalid_request", "operation_failed", or null.
-
-
-
Exception com.chargebee.v4.exceptions.BatchAPIException
class BatchAPIException extends APIException implements Serializable -
Exception com.chargebee.v4.exceptions.ChargebeeException
class ChargebeeException extends RuntimeException implements Serializable -
Exception com.chargebee.v4.exceptions.ClientErrorException
class ClientErrorException extends HttpException implements Serializable -
Exception com.chargebee.v4.exceptions.ConfigurationException
class ConfigurationException extends ChargebeeException implements Serializable -
Exception com.chargebee.v4.exceptions.HttpException
class HttpException extends TransportException implements Serializable-
Serialized Fields
-
response
Response response
-
statusCode
int statusCode
-
-
-
Exception com.chargebee.v4.exceptions.InvalidRequestException
class InvalidRequestException extends APIException implements Serializable -
Exception com.chargebee.v4.exceptions.NetworkException
class NetworkException extends TransportException implements Serializable -
Exception com.chargebee.v4.exceptions.OperationFailedException
class OperationFailedException extends APIException implements Serializable -
Exception com.chargebee.v4.exceptions.PaymentException
class PaymentException extends APIException implements Serializable -
Exception com.chargebee.v4.exceptions.ServerErrorException
class ServerErrorException extends HttpException implements Serializable -
Exception com.chargebee.v4.exceptions.TimeoutException
class TimeoutException extends TransportException implements Serializable-
Serialized Fields
-
timeoutType
String timeoutType
-
-
-
Exception com.chargebee.v4.exceptions.TransportException
class TransportException extends ChargebeeException implements Serializable-
Serialized Fields
-
request
Request request
-
-
-
Exception com.chargebee.v4.exceptions.UbbBatchIngestionInvalidRequestException
class UbbBatchIngestionInvalidRequestException extends APIException implements Serializable
-
-
Package com.chargebee.v4.webhook
-
Exception com.chargebee.v4.webhook.WebhookEventHandler.WebhookException
class WebhookException extends RuntimeException implements Serializable
-