All Classes and Interfaces
Class
Description
Deprecated.
Deprecated.
Deprecated.
Deprecated.
An object that converts literal text into a format safe for inclusion in a
particular context (such as an XML document).
Deprecated.
Deprecated.
To represent list output of ChargeBee APIs (like getting list of subscriptions !!)
represents each entry in this result-list
A
UnicodeEscaper that escapes some set of Java characters using
the URI percent encoding scheme.Deprecated.
Base class for the ChargeBee model objects
Util class to create concatenated string !!
Deprecated.
Deprecated.
Deprecated.
An
Escaper that converts literal text into a format safe for
inclusion in a particular context (such as an XML document).