Package com.chargebee

Class Environment

java.lang.Object
com.chargebee.Environment

public class Environment extends Object
  • Field Details

    • apiKey

      public final String apiKey
      You can generate API keys from the ChargeBee web interface.
    • siteName

      public final String siteName
      Your chargebee subdomain. Could be your sandbox or production.
    • connectTimeout

      public int connectTimeout
      Timeout value, in milliseconds, to be used when trying to conect to the chargebee api server. If the timeout expires before the connection can be established, a java.net.SocketTimeoutException is raised. A timeout of zero is interpreted as an infinite timeout.
    • readTimeout

      public int readTimeout
      Timeout value, in milliseconds, to be used when reading response from the chargebee api server. If the timeout expires before there is data available for read, a java.net.SocketTimeoutException is raised. A timeout of zero is interpreted as an infinite timeout.
    • retryConfig

      public RetryConfig retryConfig
    • enableDebugLogging

      public boolean enableDebugLogging
    • CHARSET

      public static final String CHARSET
      See Also:
    • API_VERSION

      public static final String API_VERSION
      See Also:
    • LIBRARY_VERSION

      public static final String LIBRARY_VERSION
      See Also:
  • Constructor Details

  • Method Details

    • configure

      public static void configure(String siteName, String apikey)
    • reqInterceptor

      public static void reqInterceptor(RequestInterceptor reqInterceptor)
    • reqInterceptor

      public RequestInterceptor reqInterceptor()
    • defaultConfig

      public static Environment defaultConfig()
    • apiBaseUrl

      public String apiBaseUrl()
    • apiBaseUrlWithSubDomain

      public String apiBaseUrlWithSubDomain(String subDomain)
    • updateConnectTimeoutInMillis

      public static void updateConnectTimeoutInMillis(int connectTimeout)
    • updateReadTimeoutInMillis

      public static void updateReadTimeoutInMillis(int readTimeout)
    • updateRetryConfig

      public void updateRetryConfig(RetryConfig retryConfig)
    • updateEnableDebugLogging

      public void updateEnableDebugLogging(boolean enableDebugLogging)