public class Environment extends Object
| Modifier and Type | Field and Description |
|---|---|
static String |
API_VERSION |
String |
apiKey
You can generate API keys from the ChargeBee web interface.
|
static String |
CHARSET |
int |
connectTimeout
Timeout value, in milliseconds, to be used when trying to conect to the
chargebee api server.
|
static String |
LIBRARY_VERSION |
int |
readTimeout
Timeout value, in milliseconds, to be used when reading response from the
chargebee api server.
|
String |
siteName
Your chargebee subdomain.
|
| Constructor and Description |
|---|
Environment(String siteName,
String apiKey) |
Environment(String siteName,
String apiKey,
RequestInterceptor reqInterceptor) |
| Modifier and Type | Method and Description |
|---|---|
String |
apiBaseUrl() |
static void |
configure(String siteName,
String apikey) |
static Environment |
defaultConfig() |
RequestInterceptor |
reqInterceptor() |
static void |
reqInterceptor(RequestInterceptor reqInterceptor) |
public final String apiKey
public final String siteName
public int connectTimeout
public int readTimeout
public static final String CHARSET
public static final String API_VERSION
public static final String LIBRARY_VERSION
public Environment(String siteName, String apiKey, RequestInterceptor reqInterceptor)
public static void reqInterceptor(RequestInterceptor reqInterceptor)
public RequestInterceptor reqInterceptor()
public static Environment defaultConfig()
public String apiBaseUrl()
Copyright © 2020 ChargeBee. All Rights Reserved.