public static enum Customer.PaymentMethod.Type extends Enum<Customer.PaymentMethod.Type>
| Enum Constant and Description |
|---|
_UNKNOWN |
ALIPAY |
AMAZON_PAYMENTS |
APPLE_PAY |
BANCONTACT |
CARD |
DIRECT_DEBIT |
DOTPAY |
GENERIC |
GIROPAY |
GOOGLE_PAY |
IDEAL |
PAYPAL_EXPRESS_CHECKOUT |
SOFORT |
UNIONPAY |
WECHAT_PAY |
| Modifier and Type | Method and Description |
|---|---|
static Customer.PaymentMethod.Type |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static Customer.PaymentMethod.Type[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Customer.PaymentMethod.Type CARD
public static final Customer.PaymentMethod.Type PAYPAL_EXPRESS_CHECKOUT
public static final Customer.PaymentMethod.Type AMAZON_PAYMENTS
public static final Customer.PaymentMethod.Type DIRECT_DEBIT
public static final Customer.PaymentMethod.Type GENERIC
public static final Customer.PaymentMethod.Type ALIPAY
public static final Customer.PaymentMethod.Type UNIONPAY
public static final Customer.PaymentMethod.Type APPLE_PAY
public static final Customer.PaymentMethod.Type WECHAT_PAY
public static final Customer.PaymentMethod.Type IDEAL
public static final Customer.PaymentMethod.Type GOOGLE_PAY
public static final Customer.PaymentMethod.Type SOFORT
public static final Customer.PaymentMethod.Type BANCONTACT
public static final Customer.PaymentMethod.Type GIROPAY
public static final Customer.PaymentMethod.Type DOTPAY
public static final Customer.PaymentMethod.Type _UNKNOWN
public static Customer.PaymentMethod.Type[] values()
for (Customer.PaymentMethod.Type c : Customer.PaymentMethod.Type.values()) System.out.println(c);
public static Customer.PaymentMethod.Type valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2020 ChargeBee. All Rights Reserved.