public static enum PaymentIntent.PaymentMethodType extends Enum<PaymentIntent.PaymentMethodType>
| Enum Constant and Description |
|---|
_UNKNOWN |
BANCONTACT |
CARD |
DOTPAY |
GIROPAY |
GOOGLE_PAY |
IDEAL |
SOFORT |
| Modifier and Type | Method and Description |
|---|---|
static PaymentIntent.PaymentMethodType |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static PaymentIntent.PaymentMethodType[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final PaymentIntent.PaymentMethodType CARD
public static final PaymentIntent.PaymentMethodType IDEAL
public static final PaymentIntent.PaymentMethodType SOFORT
public static final PaymentIntent.PaymentMethodType BANCONTACT
public static final PaymentIntent.PaymentMethodType GOOGLE_PAY
public static final PaymentIntent.PaymentMethodType DOTPAY
public static final PaymentIntent.PaymentMethodType GIROPAY
public static final PaymentIntent.PaymentMethodType _UNKNOWN
public static PaymentIntent.PaymentMethodType[] values()
for (PaymentIntent.PaymentMethodType c : PaymentIntent.PaymentMethodType.values()) System.out.println(c);
public static PaymentIntent.PaymentMethodType valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2020 ChargeBee. All Rights Reserved.