com.chargebee.models
Enum PaymentIntent.PaymentMethodType

java.lang.Object
  extended by java.lang.Enum<PaymentIntent.PaymentMethodType>
      extended by com.chargebee.models.PaymentIntent.PaymentMethodType
All Implemented Interfaces:
Serializable, Comparable<PaymentIntent.PaymentMethodType>
Enclosing class:
PaymentIntent

public static enum PaymentIntent.PaymentMethodType
extends Enum<PaymentIntent.PaymentMethodType>


Enum Constant Summary
_UNKNOWN
           
BANCONTACT
           
CARD
           
DOTPAY
           
GIROPAY
           
GOOGLE_PAY
           
IDEAL
           
SOFORT
           
 
Method Summary
static PaymentIntent.PaymentMethodType valueOf(String name)
          Returns the enum constant of this type with the specified name.
static PaymentIntent.PaymentMethodType[] values()
          Returns an array containing the constants of this enum type, in the order they are declared.
 
Methods inherited from class java.lang.Enum
clone, compareTo, equals, finalize, getDeclaringClass, hashCode, name, ordinal, toString, valueOf
 
Methods inherited from class java.lang.Object
getClass, notify, notifyAll, wait, wait, wait
 

Enum Constant Detail

CARD

public static final PaymentIntent.PaymentMethodType CARD

IDEAL

public static final PaymentIntent.PaymentMethodType IDEAL

SOFORT

public static final PaymentIntent.PaymentMethodType SOFORT

BANCONTACT

public static final PaymentIntent.PaymentMethodType BANCONTACT

GOOGLE_PAY

public static final PaymentIntent.PaymentMethodType GOOGLE_PAY

DOTPAY

public static final PaymentIntent.PaymentMethodType DOTPAY

GIROPAY

public static final PaymentIntent.PaymentMethodType GIROPAY

_UNKNOWN

public static final PaymentIntent.PaymentMethodType _UNKNOWN
Method Detail

values

public static PaymentIntent.PaymentMethodType[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:
for (PaymentIntent.PaymentMethodType c : PaymentIntent.PaymentMethodType.values())
    System.out.println(c);

Returns:
an array containing the constants of this enum type, in the order they are declared

valueOf

public static PaymentIntent.PaymentMethodType valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)

Parameters:
name - the name of the enum constant to be returned.
Returns:
the enum constant with the specified name
Throws:
IllegalArgumentException - if this enum type has no constant with the specified name
NullPointerException - if the argument is null


Copyright © 2020 ChargeBee. All Rights Reserved.