com.chargebee.models
Enum PaymentIntent.PaymentMethodType
java.lang.Object
java.lang.Enum<PaymentIntent.PaymentMethodType>
com.chargebee.models.PaymentIntent.PaymentMethodType
- All Implemented Interfaces:
- Serializable, Comparable<PaymentIntent.PaymentMethodType>
- Enclosing class:
- PaymentIntent
public static enum PaymentIntent.PaymentMethodType
- extends Enum<PaymentIntent.PaymentMethodType>
CARD
public static final PaymentIntent.PaymentMethodType CARD
IDEAL
public static final PaymentIntent.PaymentMethodType IDEAL
SOFORT
public static final PaymentIntent.PaymentMethodType SOFORT
BANCONTACT
public static final PaymentIntent.PaymentMethodType BANCONTACT
GOOGLE_PAY
public static final PaymentIntent.PaymentMethodType GOOGLE_PAY
DOTPAY
public static final PaymentIntent.PaymentMethodType DOTPAY
GIROPAY
public static final PaymentIntent.PaymentMethodType GIROPAY
_UNKNOWN
public static final PaymentIntent.PaymentMethodType _UNKNOWN
values
public static PaymentIntent.PaymentMethodType[] values()
- Returns an array containing the constants of this enum type, in
the order they are declared. This method may be used to iterate
over the constants as follows:
for (PaymentIntent.PaymentMethodType c : PaymentIntent.PaymentMethodType.values())
System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in
the order they are declared
valueOf
public static PaymentIntent.PaymentMethodType valueOf(String name)
- Returns the enum constant of this type with the specified name.
The string must match exactly an identifier used to declare an
enum constant in this type. (Extraneous whitespace characters are
not permitted.)
- Parameters:
name - the name of the enum constant to be returned.
- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException - if this enum type has no constant
with the specified name
NullPointerException - if the argument is null
Copyright © 2020 ChargeBee. All Rights Reserved.