com.chargebee.models
Enum QuoteLineGroup.ChargeEvent
java.lang.Object
java.lang.Enum<QuoteLineGroup.ChargeEvent>
com.chargebee.models.QuoteLineGroup.ChargeEvent
- All Implemented Interfaces:
- Serializable, Comparable<QuoteLineGroup.ChargeEvent>
- Enclosing class:
- QuoteLineGroup
public static enum QuoteLineGroup.ChargeEvent
- extends Enum<QuoteLineGroup.ChargeEvent>
IMMEDIATE
public static final QuoteLineGroup.ChargeEvent IMMEDIATE
SUBSCRIPTION_CREATION
public static final QuoteLineGroup.ChargeEvent SUBSCRIPTION_CREATION
TRIAL_START
public static final QuoteLineGroup.ChargeEvent TRIAL_START
SUBSCRIPTION_CHANGE
public static final QuoteLineGroup.ChargeEvent SUBSCRIPTION_CHANGE
SUBSCRIPTION_RENEWAL
public static final QuoteLineGroup.ChargeEvent SUBSCRIPTION_RENEWAL
_UNKNOWN
public static final QuoteLineGroup.ChargeEvent _UNKNOWN
values
public static QuoteLineGroup.ChargeEvent[] values()
- Returns an array containing the constants of this enum type, in
the order they are declared. This method may be used to iterate
over the constants as follows:
for (QuoteLineGroup.ChargeEvent c : QuoteLineGroup.ChargeEvent.values())
System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in
the order they are declared
valueOf
public static QuoteLineGroup.ChargeEvent valueOf(String name)
- Returns the enum constant of this type with the specified name.
The string must match exactly an identifier used to declare an
enum constant in this type. (Extraneous whitespace characters are
not permitted.)
- Parameters:
name - the name of the enum constant to be returned.
- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException - if this enum type has no constant
with the specified name
NullPointerException - if the argument is null
Copyright © 2020 ChargeBee. All Rights Reserved.