| Package | Description |
|---|---|
| com.chargebee.models |
| Modifier and Type | Method and Description |
|---|---|
BusinessEntityTransfer.ReasonCode |
BusinessEntityTransfer.reasonCode() |
static BusinessEntityTransfer.ReasonCode |
BusinessEntityTransfer.ReasonCode.valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static BusinessEntityTransfer.ReasonCode[] |
BusinessEntityTransfer.ReasonCode.values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
Copyright © 2024 ChargeBee. All rights reserved.