| Package | Description |
|---|---|
| com.chargebee.models | |
| com.chargebee.models.enums |
| Modifier and Type | Method and Description |
|---|---|
EntityCode |
Customer.entityCode() |
| Modifier and Type | Method and Description |
|---|---|
Subscription.CreateRequest |
Subscription.CreateRequest.customerEntityCode(EntityCode customerEntityCode) |
Subscription.ImportSubscriptionRequest |
Subscription.ImportSubscriptionRequest.customerEntityCode(EntityCode customerEntityCode) |
Estimate.CreateSubscriptionRequest |
Estimate.CreateSubscriptionRequest.customerEntityCode(EntityCode customerEntityCode) |
Estimate.CreateSubItemEstimateRequest |
Estimate.CreateSubItemEstimateRequest.customerEntityCode(EntityCode customerEntityCode) |
Customer.CreateRequest |
Customer.CreateRequest.entityCode(EntityCode entityCode) |
Customer.UpdateRequest |
Customer.UpdateRequest.entityCode(EntityCode entityCode) |
| Modifier and Type | Method and Description |
|---|---|
static EntityCode |
EntityCode.valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static EntityCode[] |
EntityCode.values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
Copyright © 2021 ChargeBee. All Rights Reserved.