Enum Class BadRequestApiErrorCode
- All Implemented Interfaces:
ApiErrorCode,Serializable,Comparable<BadRequestApiErrorCode>,Constable
API error codes for HTTP 400 responses
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionRepresents an unknown or unrecognized error code.API error code: configuration_incompatibleAPI error code: duplicate_entryAPI error code: invalid_requestAPI error code: param_wrong_valueAPI error code: payment_gateway_currency_incompatibleAPI error code: payment_intent_invalidAPI error code: payment_intent_invalid_amountAPI error code: payment_method_not_presentAPI error code: payment_method_verification_failedAPI error code: payment_processing_failedAPI error code: resource_limit_exceededAPI error code: resource_limit_exhausted -
Method Summary
Modifier and TypeMethodDescriptionstatic BadRequestApiErrorCodefromString(String value) Convert an API string value to the corresponding enum constant.getValue()Get the string value of this error code as returned by the API.booleanisKnown()Check if this error code is a known (non-unknown) value.static BadRequestApiErrorCodeReturns the enum constant of this class with the specified name.static BadRequestApiErrorCode[]values()Returns an array containing the constants of this enum class, in the order they are declared.Methods inherited from class java.lang.Enum
clone, compareTo, describeConstable, equals, finalize, getDeclaringClass, hashCode, name, ordinal, toString, valueOfMethods inherited from interface com.chargebee.v4.exceptions.codes.ApiErrorCode
name
-
Enum Constant Details
-
PAYMENT_INTENT_INVALID_AMOUNT
API error code: payment_intent_invalid_amount -
CONFIGURATION_INCOMPATIBLE
API error code: configuration_incompatible -
PAYMENT_INTENT_INVALID
API error code: payment_intent_invalid -
INVALID_REQUEST
API error code: invalid_request -
PAYMENT_METHOD_VERIFICATION_FAILED
API error code: payment_method_verification_failed -
PAYMENT_PROCESSING_FAILED
API error code: payment_processing_failed -
RESOURCE_LIMIT_EXHAUSTED
API error code: resource_limit_exhausted -
DUPLICATE_ENTRY
API error code: duplicate_entry -
PARAM_WRONG_VALUE
API error code: param_wrong_value -
PAYMENT_METHOD_NOT_PRESENT
API error code: payment_method_not_present -
RESOURCE_LIMIT_EXCEEDED
API error code: resource_limit_exceeded -
PAYMENT_GATEWAY_CURRENCY_INCOMPATIBLE
API error code: payment_gateway_currency_incompatible -
_UNKNOWN
Represents an unknown or unrecognized error code. This allows forward compatibility when new error codes are added.
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getValue
Get the string value of this error code as returned by the API.- Specified by:
getValuein interfaceApiErrorCode- Returns:
- the API string value, or null for _UNKNOWN
-
fromString
Convert an API string value to the corresponding enum constant. Returns _UNKNOWN for unrecognized values to ensure forward compatibility.- Parameters:
value- the API string value- Returns:
- the corresponding enum constant, or _UNKNOWN if not recognized
-
isKnown
public boolean isKnown()Check if this error code is a known (non-unknown) value.- Specified by:
isKnownin interfaceApiErrorCode- Returns:
- true if this is a recognized error code
-