Package com.chargebee.v4.models.addon
Class Addon
java.lang.Object
com.chargebee.v4.models.addon.Addon
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic enumstatic enumstatic enumstatic enumstatic enumstatic enumstatic enumstatic enumstatic classstatic classstatic enum -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanstatic AddonfromJson(com.google.gson.JsonObject jsonObj) static Addonstatic AddongetCustomField(String fieldName) Returns the value of a specific custom field.Returns a map of custom fields.getId()getName()getPrice()getSku()getTiers()getType()Deprecated.getUnit()inthashCode()toString()
-
Constructor Details
-
Addon
public Addon()
-
-
Method Details
-
getId
-
getName
-
getInvoiceName
-
getDescription
-
getPricingModel
-
getType
Deprecated. -
getChargeType
-
getPrice
-
getCurrencyCode
-
getPeriod
-
getPeriodUnit
-
getUnit
-
getStatus
-
getArchivedAt
-
getEnabledInPortal
-
getTaxCode
-
getHsnCode
-
getTaxjarProductCode
-
getAvalaraSaleType
-
getAvalaraTransactionType
-
getAvalaraServiceType
-
getSku
-
getAccountingCode
-
getAccountingCategory1
-
getAccountingCategory2
-
getAccountingCategory3
-
getAccountingCategory4
-
getIsShippable
-
getShippingFrequencyPeriod
-
getShippingFrequencyPeriodUnit
-
getResourceVersion
-
getUpdatedAt
-
getPriceInDecimal
-
getIncludedInMrr
-
getChannel
-
getProrationType
-
getInvoiceNotes
-
getTaxable
-
getTaxProfileId
-
getMetaData
-
getShowDescriptionInInvoices
-
getShowDescriptionInQuotes
-
getTiers
-
getTaxProvidersFields
-
getCustomFields
Returns a map of custom fields. Custom fields are dynamic properties that follow the pattern cf_* (e.g., cf_custom_field_name).- Returns:
- map containing all custom fields
-
getCustomField
Returns the value of a specific custom field.- Parameters:
fieldName- the name of the custom field (e.g., "cf_custom_field_name")- Returns:
- the value of the custom field, or null if not present
-
fromJson
-
fromJson
-
fromJson
-
toString
-
equals
-
hashCode
public int hashCode()
-